Curation
========
There are several curation workflows implemented in :mod:`bioregistry.curation`.

Bulk Import
-----------
.. automodapi:: bioregistry.curation.bulk_import

Semi-automated Literature Curation
----------------------------------
.. automodapi:: bioregistry.curation.literature
